<!DOCTYPE html>
<html>
<head>
    <title>JupyterHub Apps</title>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <script src="https://cdn.tailwindcss.com"></script>
    <link rel="preconnect" href="https://fonts.googleapis.com">
    <link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>
    <link href="https://fonts.googleapis.com/css2?family=Mukta:wght@500&display=swap" rel="stylesheet">
    <style>
        /* Your custom CSS goes here */
        body {
            font-family: Mukta, sans-serif;
            background-color: #f0f0f0;
        }

        h1 {
            font-family: Mukta, sans-serif;
        }

    </style>

</head>
<body>
<header class="bg-gray-900 text-white py-6">
    <div class="container mx-auto">
        <nav class="flex justify-between items-center">
            <img src="{{ jhub_app_icon }}"
                 alt="JHub Apps User Logo"
                 width="50" height="50"
            >
            <a href="#" class="text-4xl font-semibold">{{ jhub_app_title }}</a>
            <ul class="flex space-x-4">
                <li>
                    <button class="bg-blue-500 hover:bg-blue-700 text-white font-bold py-2 px-4 rounded">
                        <a href="/hub/home" class="hover:text-gray-400">Home</a>
                    </button>
                </li>

            </ul>
        </nav>
    </div>
</header>
<div class="container mx-auto mt-8 px-4">
    {{ script|safe }}
</div>
</body>
</html>
