<div class="form-group">
    <label for="args">Extra notebook CLI arguments</label>
    <input name="args" class="form-control"
           placeholder="e.g. --debug"></input>
</div>
<div class="form-group">
    <label for="env">Environment variables (one per line)</label>
    <textarea class="form-control" name="env">{{ env }}</textarea>
</div>
