{% extends "page.html" %} {% block main %}

<div id="root"></div>
<script src="/services/japps/static/js/index.js?v={{version_hash}}"></script>
<link
  rel="stylesheet"
  href="/services/japps/static/css/index.css?v={{version_hash}}"
/>

{% endblock %}
