import { User } from '../types/user';

export const userData: User = {
  firstName: 'John',
  lastName: 'Doe',
  displayName: 'John Doe',
  emailAddress: 'johndoe@test.com',
  phoneNumber: '123-456-7890',
};
