// Note: This is only used for local development
window.jhdata = {
  base_url: '/hub/',
  prefix: '/',
  user: 'admin',
  admin_access: false,
  options_form: false,
  xsrf_token: '2|12345|12345|12345`',
};
